@@ -121,6 +121,11 @@ def isaid_classes():
     ]
 
 
+def stare_classes():
+    """stare class names for external use."""
+    return ['background', 'vessel']
+
+
 def cityscapes_palette():
     """Cityscapes palette for external use."""
     return [[128, 64, 128], [244, 35, 232], [70, 70, 70], [102, 102, 156],
@@ -255,6 +260,11 @@ def isaid_palette():
             [0, 127, 255], [0, 100, 155]]
 
 
+def stare_palette():
+    """STARE palette for external use."""
+    return [[120, 120, 120], [6, 230, 230]]
+
+
 dataset_aliases = {
     'cityscapes': ['cityscapes'],
     'ade': ['ade', 'ade20k'],
@@ -267,7 +277,8 @@ dataset_aliases = {
         'coco-stuff10k', 'coco-stuff164k', 'coco_stuff', 'coco_stuff10k',
         'coco_stuff164k'
     ],
-    'isaid': ['isaid', 'iSAID']
+    'isaid': ['isaid', 'iSAID'],
+    'stare': ['stare', 'STARE']
 }
 
 
